/* \file drivers.c

   \brief test if the different output drivers work in C
*/

#include <magics_api.h>

int main()
{
	const char *formats[] = {"svg","kml","ps","pdf","png"};
	const int num = 5;

	/* open magics and set the output device */
	mag_open();
	mag_set1c("output_formats", formats, num);
	mag_setc("output_name", "driver_test");
	mag_coast();

	mag_close();

	return 0;
}
